<!-- ![logo](_media.asdf-vm-logo.svg) -->

# asdf-vm

> Manage multiple runtime versions with a single CLI tool

<!-- insert asciinema or other gif here -->

- Bash, Zsh, Fish
- Node.js, Ruby, Python, Elixir ... [your favourite language?](plugins-all?id=plugin-list)
- Extend with a simple plugin system

[GitHub](https://github.com/asdf-vm/asdf)
[Get Started](core-manage-asdf-vm)
